==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/mn-MN/mail.php <==
<?php

return [
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'a_user_canceled' => 'Хэрэглэгч вэбсайт дээрх зүйл хүсэлтийг цуцалсан байна',
    'a_user_requested' => 'Хэрэглэгч вэбсайт дээрх зүйлийг хүссэн байна',
    'accessory_name' => 'Дагалдах хэрэгслийн нэр:',
    'additional_notes' => 'Нэмэлт тайлбар:',
    'admin_has_created' => 'Администратор танд зориулж дараах вэбсайт дээр акаунт үүсгэсэн байна.',
    'asset' => 'Актив:',
    'asset_name' => 'Хөрөнгийн нэр:',
    'asset_requested' => 'Хөрөнгө хүссэн',
    'asset_tag' => 'Хөрөнгийн шошго',
    'assigned_to' => 'Томилогдсон',
    'best_regards' => 'Хамгийн сайн нь,',
    'canceled' => 'Цуцалсан:',
    'checkin_date' => 'Огноо шалгах:',
    'checkout_date' => 'Тооцоо хийх өдөр:',
    'click_to_confirm' => 'Вэбсайтаа баталгаажуулахын тулд дараах холбоос дээр дарна уу:',
    'click_on_the_link_accessory' => 'Дагалдах хэрэгслийг хүлээн авсан гэдгээ батлахын тулд доорх холбоос дээр дарна уу.',
    'click_on_the_link_asset' => 'Хөрөнгийг хүлээн авсан гэдгээ батлахын тулд доорх холбоос дээр дарна уу.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Одоогийн QTY',
    'Days' => 'Өдөр',
    'days' => 'Өдөр',
    'expecting_checkin_date' => 'Хүлээгдэж буй хугацаа:',
    'expires' => 'Хугацаа дуусна',
    'Expiring_Assets_Report' => 'Хугацаа дууссан активын тайлан.',
    'Expiring_Licenses_Report' => 'Хугацаа дуусгавар болсон лицензийн тайлан.',
    'hello' => 'Сайн уу',
    'hi' => 'Сайн уу',
    'i_have_read' => 'Би ашиглалтын нөхцөлийг уншиж, зөвшөөрч, энэ зүйлийг хүлээн авсан.',
    'item' => 'Зүйл:',
    'Item_Request_Canceled' => 'Зүйлийн хүсэлтийг хүчингүй болгох',
    'Item_Requested' => 'Барааны хүсэлт',
    'link_to_update_password' => 'Вэбсайтаа шинэчлэхийн тулд дараах холбоос дээр дарна уу:',
    'login_first_admin' => 'Слайд-IT-г суулгахын тулд доорх итгэмжлэлүүдийг ашиглана уу:',
    'login' => 'Нэвтрэх:',
    'Low_Inventory_Report' => 'Бага нөөцийн тайлан',
    'inventory_report' => 'Inventory Report',
    'min_QTY' => 'Min QTY',
    'name' => 'Нэр',
    'new_item_checked' => 'Таны нэрээр шинэ зүйл шалгасан бөгөөд дэлгэрэнгүй мэдээлэл доор байна.',
    'password' => 'Нууц үг:',
    'password_reset' => 'Нууц үг шинэчлэх',

    'read_the_terms' => 'Доорх хэрэглээний нөхцөлийг уншина уу.',
    'read_the_terms_and_click' => 'Доорх хэрэглээний нөхцөлийг уншина уу, доод тал дээрх холбоос дээр дарж уншсанаа баталгаажуулж, ашиглалтын нөхцөлийг хүлээн зөвшөөрч, уг хөрөнгийг хүлээн авсан болно.',
    'requested' => 'Хүсэлт гаргасан:',
    'reset_link' => 'Таны нууц үгээ шинэчлэх линк',
    'reset_password' => 'Нууц үгээ дахин тохируулах бол энд дарна уу:',
    'serial' => 'Сериал',
    'supplier' => 'Нийлүүлэгч',
    'tag' => 'Таг',
    'test_email' => 'Слайк-IT-с тест хийх мэйл',
    'test_mail_text' => 'Энэ бол Snipe-IT Asset Management System-ийн тест юм. Хэрэв та үүнийг авсан бол имэйл ажиллаж байна :)',
    'the_following_item' => 'Дараах зүйлүүдийг шалгасан байна:',
    'low_inventory_alert' => ':count ширхэг барааны нөөц дуусаж байна.|:count ширхэг барааны нөөц дуусаж байна.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => ':count ширхэг лизенц :threshhold өдрийн дотор дуусна.|:count ширхэг лизенц :threshhold өдрийн дотор дуусна.',
    'to_reset' => 'Та өөрийн: веб нууц үгээ шинэчлэхийн тулд энэ маягтыг бөглөнө үү:',
    'type' => 'Төрөл',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Хэрэглэгч',
    'username' => 'Нэвтрэх нэр',
    'welcome' => 'Тавтай морилно уу: нэр',
    'welcome_to' => 'Тавтай морилно уу: Вэб хуудас!',
    'your_credentials' => 'Таны Snipe-IT итгэмжлэлүүд',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets',
    'rights_reserved' => 'All rights reserved.',
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/mn-MN/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'Өдөр',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expiring_Assets_Report' => 'Хугацаа дууссан активын тайлан.',
    'Expiring_Licenses_Report' => 'Хугацаа дуусгавар болсон лицензийн тайлан.',
    'Item_Request_Canceled' => 'Зүйлийн хүсэлтийг хүчингүй болгох',
    'Item_Requested' => 'Барааны хүсэлт',
    'License_Checkin_Notification' => 'License checked in',
    'License_Checkout_Notification' => 'License checked out',
    'Low_Inventory_Report' => 'Бага нөөцийн тайлан',
    'a_user_canceled' => 'Хэрэглэгч вэбсайт дээрх зүйл хүсэлтийг цуцалсан байна',
    'a_user_requested' => 'Хэрэглэгч вэбсайт дээрх зүйлийг хүссэн байна',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'accessory_name' => 'Дагалдах хэрэгслийн нэр:',
    'additional_notes' => 'Нэмэлт тайлбар:',
    'admin_has_created' => 'Администратор танд зориулж дараах вэбсайт дээр акаунт үүсгэсэн байна.',
    'asset' => 'Актив:',
    'asset_name' => 'Хөрөнгийн нэр:',
    'asset_requested' => 'Хөрөнгө хүссэн',
    'asset_tag' => 'Хөрөнгийн шошго',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'assigned_to' => 'Томилогдсон',
    'best_regards' => 'Хамгийн сайн нь,',
    'canceled' => 'Цуцалсан:',
    'checkin_date' => 'Огноо шалгах:',
    'checkout_date' => 'Тооцоо хийх өдөр:',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Дагалдах хэрэгслийг хүлээн авсан гэдгээ батлахын тулд доорх холбоос дээр дарна уу.',
    'click_on_the_link_asset' => 'Хөрөнгийг хүлээн авсан гэдгээ батлахын тулд доорх холбоос дээр дарна уу.',
    'click_to_confirm' => 'Вэбсайтаа баталгаажуулахын тулд дараах холбоос дээр дарна уу:',
    'current_QTY' => 'Одоогийн QTY',
    'days' => 'Өдөр',
    'expecting_checkin_date' => 'Хүлээгдэж буй хугацаа:',
    'expires' => 'Хугацаа дуусна',
    'hello' => 'Сайн уу',
    'hi' => 'Сайн уу',
    'i_have_read' => 'Би ашиглалтын нөхцөлийг уншиж, зөвшөөрч, энэ зүйлийг хүлээн авсан.',
    'inventory_report' => 'Inventory Report',
    'item' => 'Зүйл:',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => ':count ширхэг лизенц :threshhold өдрийн дотор дуусна.|:count ширхэг лизенц :threshhold өдрийн дотор дуусна.',
    'link_to_update_password' => 'Вэбсайтаа шинэчлэхийн тулд дараах холбоос дээр дарна уу:',
    'login' => 'Нэвтрэх:',
    'login_first_admin' => 'Слайд-IT-г суулгахын тулд доорх итгэмжлэлүүдийг ашиглана уу:',
    'low_inventory_alert' => ':count ширхэг барааны нөөц дуусаж байна.|:count ширхэг барааны нөөц дуусаж байна.',
    'min_QTY' => 'Min QTY',
    'name' => 'Нэр',
    'new_item_checked' => 'Таны нэрээр шинэ зүйл шалгасан бөгөөд дэлгэрэнгүй мэдээлэл доор байна.',
    'notes' => 'Тэмдэглэл',
    'password' => 'Нууц үг:',
    'password_reset' => 'Нууц үг шинэчлэх',
    'read_the_terms' => 'Доорх хэрэглээний нөхцөлийг уншина уу.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'Хүсэлт гаргасан:',
    'reset_link' => 'Таны нууц үгээ шинэчлэх линк',
    'reset_password' => 'Нууц үгээ дахин тохируулах бол энд дарна уу:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'Сериал',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Нийлүүлэгч',
    'tag' => 'Таг',
    'test_email' => 'Слайк-IT-с тест хийх мэйл',
    'test_mail_text' => 'Энэ бол Snipe-IT Asset Management System-ийн тест юм. Хэрэв та үүнийг авсан бол имэйл ажиллаж байна :)',
    'the_following_item' => 'Дараах зүйлүүдийг шалгасан байна:',
    'to_reset' => 'Та өөрийн: веб нууц үгээ шинэчлэхийн тулд энэ маягтыг бөглөнө үү:',
    'type' => 'Төрөл',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Хэрэглэгч',
    'username' => 'Нэвтрэх нэр',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Тавтай морилно уу: нэр',
    'welcome_to' => 'Тавтай морилно уу: Вэб хуудас!',
    'your_assets' => 'View Your Assets',
    'your_credentials' => 'Таны Snipe-IT итгэмжлэлүүд',
    'mail_sent' => 'Mail sent successfully!',
];
